@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -10,7 +10,7 @@
 # http://www.wtfpl.net/ for more details.
 
 package Chess::Plisco::EPD;
-$Chess::Plisco::EPD::VERSION = 'v0.8.0';
+$Chess::Plisco::EPD::VERSION = '0.3';
 use strict;
 use integer;
 
@@ -20,32 +20,25 @@ use Locale::TextDomain qw('Chess-Plisco');
 use Chess::Plisco::EPD::Record;
 
 sub new {
-	my ($class, $arg, @args) = @_;
-
-	my %options = @args;
-	if (@args == 1 && 'HASH' eq ref $args[0]) {
-		%options = %{$args[0]};
-	}
-	my $filename = $options{filename};
-	my $pseudo_legal = $options{pseudo_legal};
+	my ($class, $arg, $filename) = @_;
 
 	my $reftype = (reftype $arg) || '';
 	my @lines;
 	if ('SCALAR' eq $reftype) {
 		@lines = split /\n/, $$arg;
-		$filename //= __"[in-memory string]";
+		$filename = __"[in-memory string]";
 	} elsif ('ARRAY' eq $reftype) {
 		@lines = @$arg;
-		$filename //= __"[in-memory array]";
+		$filename = __"[in-memory array]";
 	} elsif ('GLOB' eq $reftype) {
 		@lines = <$arg>;
-		$filename //= __"[file-handle]";
+		$filename ||= __"[file-handle]";
 	} else {
 		open my $fh, '<', $arg
 			or die __x("cannot open '{filename}' for reading: {error}!\n",
 				filename => $arg,
 				error => $!);
-		$filename //= $arg;
+		$filename ||= $arg;
 		@lines = <$fh>;
 	}
 
@@ -58,7 +51,7 @@ sub new {
 		$line =~ s/ws+$//;
 		next if !length $line;
 
-		my $record = eval { Chess::Plisco::EPD::Record->new($line, $pseudo_legal) };
+		my $record = eval { Chess::Plisco::EPD::Record->new($line) };
 		if ($@) {
 			die "$filename:$lineno: $@";
 		}
