@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -10,12 +10,10 @@
 # http://www.wtfpl.net/ for more details.
 
 package Chess::Plisco::Engine::TranspositionTable;
-$Chess::Plisco::Engine::TranspositionTable::VERSION = 'v0.8.0';
+$Chess::Plisco::Engine::TranspositionTable::VERSION = '0.3';
 use strict;
 use integer;
 
-use Chess::Plisco::Engine::Tree;
-
 use constant TT_ENTRY_SIZE => 16;
 
 use constant TT_SCORE_EXACT => 0;
@@ -68,14 +66,6 @@ sub probe {
 
 	if ($edepth >= $depth) {
 		if ($flags == TT_SCORE_EXACT) {
-			if ($value <= Chess::Plisco::Engine::Tree::MATE
-					+ Chess::Plisco::Engine::Tree::MAX_PLY) {
-					$value += ($edepth - $depth);
-			} elsif ($value >= -Chess::Plisco::Engine::Tree::MATE
-					- Chess::Plisco::Engine::Tree::MAX_PLY) {
-					$value -= ($edepth - $depth);
-			}
-
 			return $value;
 		}
 
@@ -86,6 +76,8 @@ sub probe {
 		if (($flags == TT_SCORE_BETA) && ($value >= $beta)) {
 			return $beta;
 		}
+
+		# FIXME! Pass at least best move to caller.
 	}
 
 	return;
